==> haskell-httpd-shed-0.4.1.2-103.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-httpd-shed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 httpd-shed
version:              0.4.1.2
visibility:           public
id:                   httpd-shed-0.4.1.2-HXFFXFZJERT4t5M2wyW3cx
key:                  httpd-shed-0.4.1.2-HXFFXFZJERT4t5M2wyW3cx
license:              BSD-3-Clause
copyright:            (c) 2009 Andy Gill
maintainer:           Ganesh Sittampalam
author:               Andy Gill, Brandon Moore, Henning Thielemann, John Van Enk.
synopsis:             A simple web-server with an interact style API
description:
    This web server promotes a Request to IO Response function
    into a local web server. The user can decide how to interpret
    the requests, and the library is intended for implementing Ajax APIs.

category:             Network, Web
abi:                  e486d610c1af4ab6807ae8ec2da878c6
exposed:              True
exposed-modules:      Network.Shed.Httpd
import-dirs:          /usr/lib/ghc-9.6.6/site-local/httpd-shed-0.4.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/httpd-shed-0.4.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/httpd-shed-0.4.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-httpd-shed
hs-libraries:         HShttpd-shed-0.4.1.2-HXFFXFZJERT4t5M2wyW3cx
depends:
    base-4.18.2.1 network-3.1.4.0-8n0F06kM1hW6KWRJNaBKOe
    network-bsd-2.8.1.0-tw2oRH0FuUAjhgeHdG5Oa
    network-uri-2.6.4.2-69jfmnohyG88ZQKNy7a5sS

haddock-interfaces:   /usr/share/doc/haskell-httpd-shed/html/httpd-shed.haddock
haddock-html:         /usr/share/doc/haskell-httpd-shed/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-httpd-shed-0.4.1.2-104-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-httpd-shed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 httpd-shed
version:              0.4.1.2
visibility:           public
id:                   httpd-shed-0.4.1.2-JwXDJlV6q0gHUfP82q0hbJ
key:                  httpd-shed-0.4.1.2-JwXDJlV6q0gHUfP82q0hbJ
license:              BSD-3-Clause
copyright:            (c) 2009 Andy Gill
maintainer:           Ganesh Sittampalam
author:               Andy Gill, Brandon Moore, Henning Thielemann, John Van Enk.
synopsis:             A simple web-server with an interact style API
description:
    This web server promotes a Request to IO Response function
    into a local web server. The user can decide how to interpret
    the requests, and the library is intended for implementing Ajax APIs.

category:             Network, Web
abi:                  c3f2b926bc65cb2054c731cce88edfdd
exposed:              True
exposed-modules:      Network.Shed.Httpd
import-dirs:          /usr/lib/ghc-9.6.6/site-local/httpd-shed-0.4.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/httpd-shed-0.4.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/httpd-shed-0.4.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-httpd-shed
hs-libraries:         HShttpd-shed-0.4.1.2-JwXDJlV6q0gHUfP82q0hbJ
depends:
    base-4.18.2.1 network-3.1.4.0-JRitsFhJ8rKGUNW13KrLgQ
    network-bsd-2.8.1.0-D7anFlGqSCnK99qTn3SolU
    network-uri-2.6.4.2-ImBkmHhWmdwGJdqs22FerI

haddock-interfaces:   /usr/share/doc/haskell-httpd-shed/html/httpd-shed.haddock
haddock-html:         /usr/share/doc/haskell-httpd-shed/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
